SET ECHO ON;
SET TIME ON;
SET TIMING ON;

DROP INDEX "DEMO_USR"."IDX_SALE_DIM1";
DROP INDEX "DEMO_USR"."IDX_SALE_ALL_DIM";

DROP TABLE "DEMO_USR"."F_SALE";
DROP TABLE "DEMO_USR"."D_CUSTOMER";
DROP TABLE "DEMO_USR"."D_CUSTOMER_SUB_GROUP";
DROP TABLE "DEMO_USR"."D_CUSTOMER_GROUP";
DROP TABLE "DEMO_USR"."D_VENDOR";
DROP TABLE "DEMO_USR"."D_AGENCY";
DROP TABLE "DEMO_USR"."D_REGION";
DROP TABLE "DEMO_USR"."D_COUNTRY";
DROP TABLE "DEMO_USR"."D_PRODUCT";
DROP TABLE "DEMO_USR"."D_PRODUCT_SUB_FAMILY";
DROP TABLE "DEMO_USR"."D_PRODUCT_FAMILY";
DROP TABLE "DEMO_USR"."D_CALENDAR";

CREATE TABLE "DEMO_USR"."D_CALENDAR"
(
CAL_DATE DATE NOT NULL
,CAL_DAY_OF_WEEK VARCHAR2(20)
,CAL_YEARMONTH NUMBER(6)
,CAL_MONTH_OF_YEAR NUMBER(2)
,CAL_MONTH_OF_YEAR_DESC VARCHAR2(20)
,CAL_YEAR NUMBER(4)
,CAL_YEAR_DESC VARCHAR2(50)
,CONSTRAINT "PK_CALENDAR" PRIMARY KEY ("CAL_DATE") USING INDEX
)
;

CREATE TABLE "DEMO_USR"."D_PRODUCT_FAMILY"
(
PFM_ID VARCHAR2(10) NOT NULL
,PFM_DESC VARCHAR2(50)
,CONSTRAINT "PK_PRODUCT_FAMILY" PRIMARY KEY ("PFM_ID") USING INDEX
)
;

CREATE TABLE "DEMO_USR"."D_PRODUCT_SUB_FAMILY"
(
PSF_ID VARCHAR2(10) NOT NULL
,PSF_FAMILY VARCHAR2(10)
,PSF_DESC VARCHAR2(50)
,CONSTRAINT "PK_PRODUCT_SUB_FAMILY" PRIMARY KEY ("PSF_ID") USING INDEX
,CONSTRAINT "FK_PRODUCT_FAMILY" FOREIGN KEY ("PSF_FAMILY") REFERENCES "DEMO_USR"."D_PRODUCT_FAMILY" ("PFM_ID") DISABLE
)
;

CREATE TABLE "DEMO_USR"."D_PRODUCT"
(
PRO_ID VARCHAR2(10) NOT NULL
,PRO_SUB_FAMILY VARCHAR2(10)
,PRO_DESC VARCHAR2(50)
,CONSTRAINT "PK_PRODUCT" PRIMARY KEY ("PRO_ID") USING INDEX
,CONSTRAINT "FK_PRODUCT_SUB_FAMILY" FOREIGN KEY ("PRO_SUB_FAMILY") REFERENCES "DEMO_USR"."D_PRODUCT_SUB_FAMILY" ("PSF_ID") DISABLE
)
;

CREATE TABLE "DEMO_USR"."D_COUNTRY"
(
CTR_ID VARCHAR2(10) NOT NULL
,CTR_NAME VARCHAR2(50)
,CONSTRAINT "PK_COUNTRY" PRIMARY KEY ("CTR_ID") USING INDEX
)
;

CREATE TABLE "DEMO_USR"."D_REGION"
(
REG_ID VARCHAR2(10) NOT NULL
,REG_COUNTRY VARCHAR2(10)
,REG_NAME VARCHAR2(50)
,CONSTRAINT "PK_REGION" PRIMARY KEY ("REG_ID") USING INDEX
,CONSTRAINT "FK_COUNTRY" FOREIGN KEY ("REG_COUNTRY") REFERENCES "DEMO_USR"."D_COUNTRY" ("CTR_ID") DISABLE
)
;

CREATE TABLE "DEMO_USR"."D_AGENCY"
(
AGC_ID VARCHAR2(10) NOT NULL
,AGC_REGION VARCHAR2(10)
,AGC_NAME VARCHAR2(50)
,CONSTRAINT "PK_AGENCY" PRIMARY KEY ("AGC_ID") USING INDEX
,CONSTRAINT "FK_REGION" FOREIGN KEY ("AGC_REGION") REFERENCES "DEMO_USR"."D_REGION" ("REG_ID") DISABLE
)
;

CREATE TABLE "DEMO_USR"."D_VENDOR"
(
VDR_ID VARCHAR2(10) NOT NULL
,VDR_AGENCY VARCHAR2(10)
,VDR_NAME VARCHAR2(50)
,CONSTRAINT "PK_VENDOR" PRIMARY KEY ("VDR_ID") USING INDEX
,CONSTRAINT "FK_AGENCY" FOREIGN KEY ("VDR_AGENCY") REFERENCES "DEMO_USR"."D_AGENCY" ("AGC_ID") DISABLE
)
;

CREATE TABLE "DEMO_USR"."D_CUSTOMER_GROUP"
(
CGR_ID VARCHAR2(10) NOT NULL
,CGR_DESC VARCHAR2(50)
,CONSTRAINT "PK_CUSTOMER_GROUP" PRIMARY KEY ("CGR_ID") USING INDEX
)
;

CREATE TABLE "DEMO_USR"."D_CUSTOMER_SUB_GROUP"
(
CSB_ID VARCHAR2(10) NOT NULL
,CSB_GROUP VARCHAR2(10)
,CSB_DESC VARCHAR2(50)
,CONSTRAINT "PK_CUSTOMER_SUB_GROUP"PRIMARY KEY ("CSB_ID") USING INDEX
,CONSTRAINT "FK_CUSTOMER_GROUP" FOREIGN KEY ("CSB_GROUP") REFERENCES "DEMO_USR"."D_CUSTOMER_GROUP" ("CGR_ID") DISABLE
)
;

CREATE TABLE "DEMO_USR"."D_CUSTOMER"
(
CUS_ID VARCHAR2(10) NOT NULL
,CUS_SUB_GROUP VARCHAR2(10)
,CUS_NAME VARCHAR2(50)
,CONSTRAINT "PK_CUSTOMER" PRIMARY KEY ("CUS_ID") USING INDEX
,CONSTRAINT "FK_CUSTOMER_SUB_GROUP" FOREIGN KEY ("CUS_SUB_GROUP") REFERENCES "DEMO_USR"."D_CUSTOMER_SUB_GROUP" ("CSB_ID") DISABLE
)
;


CREATE TABLE "DEMO_USR"."F_SALE"
(
SAL_ID NUMBER(10,0) NOT NULL
,SAL_AMOUNT NUMBER(12,2)
,SAL_DISCOUNT_AMOUNT NUMBER(12,2)
,SAL_DATETIME DATE
,SAL_DATE DATE
,SAL_PRODUCT VARCHAR2(10)
,SAL_VENDOR VARCHAR2(10)
,SAL_CUSTOMER VARCHAR2(10)
,CONSTRAINT "PK_SALE" PRIMARY KEY ("SAL_ID") USING INDEX
,CONSTRAINT "FK_DATE" FOREIGN KEY ("SAL_DATE") REFERENCES "DEMO_USR"."D_CALENDAR" ("CAL_DATE") DISABLE
,CONSTRAINT "FK_PRODUCT" FOREIGN KEY ("SAL_PRODUCT") REFERENCES "DEMO_USR"."D_PRODUCT" ("PRO_ID") DISABLE
,CONSTRAINT "FK_VENDOR" FOREIGN KEY ("SAL_VENDOR") REFERENCES "DEMO_USR"."D_VENDOR" ("VDR_ID") DISABLE
,CONSTRAINT "FK_CUSTOMER" FOREIGN KEY ("SAL_CUSTOMER") REFERENCES "DEMO_USR"."D_CUSTOMER" ("CUS_ID") DISABLE
)
;

CREATE INDEX "DEMO_USR"."IDX_SALE_ALL_DIM" ON "DEMO_USR"."F_SALE" ("SAL_CUSTOMER", "SAL_DATE", "SAL_PRODUCT", "SAL_VENDOR" );

CREATE INDEX "DEMO_USR"."IDX_SALE_DIM1" ON "DEMO_USR"."F_SALE" ("SAL_DATE", "SAL_PRODUCT", "SAL_VENDOR");
