Set echo on;
Set autotrace off;
Set time on;
Set timing on;

DROP MATERIALIZED VIEW "DEMO_USR"."MV_SALE_MODEL_LVL2_101";

CREATE MATERIALIZED VIEW "DEMO_USR"."MV_SALE_MODEL_LVL2_101"
build immediate
enable query rewrite
AS
SELECT
	"D_CALENDAR"."CAL_YEAR"
	,"D_CUSTOMER_SUB_GROUP"."CSB_ID"
	,"D_COUNTRY"."CTR_NAME"
	,COUNT(*)
	,sum(SAL_AMOUNT)
	,sum(SAL_DISCOUNT_AMOUNT)
FROM
	"DEMO_USR"."F_SALE" "F_SALE"
	,"DEMO_USR"."D_CUSTOMER" "D_CUSTOMER"
	,"DEMO_USR"."D_CUSTOMER_SUB_GROUP" "D_CUSTOMER_SUB_GROUP"
	,"DEMO_USR"."D_VENDOR" "D_VENDOR"
	,"DEMO_USR"."D_AGENCY" "D_AGENCY"
	,"DEMO_USR"."D_REGION" "D_REGION"
	,"DEMO_USR"."D_COUNTRY" "D_COUNTRY"
	,"DEMO_USR"."D_CALENDAR" "D_CALENDAR"
WHERE
	"F_SALE"."SAL_DATE" = "D_CALENDAR"."CAL_DATE"
	AND "F_SALE"."SAL_CUSTOMER" = "D_CUSTOMER"."CUS_ID"
	AND "D_CUSTOMER"."CUS_SUB_GROUP" = "D_CUSTOMER_SUB_GROUP"."CSB_ID"
	AND "D_REGION"."REG_COUNTRY" = "D_COUNTRY"."CTR_ID"
	AND "F_SALE"."SAL_VENDOR" = "D_VENDOR"."VDR_ID"
	AND "D_VENDOR"."VDR_AGENCY" = "D_AGENCY"."AGC_ID"
	AND "D_AGENCY"."AGC_REGION" = "D_REGION"."REG_ID"
	AND "D_REGION"."REG_COUNTRY" = "D_COUNTRY"."CTR_ID"
GROUP BY
	"D_CALENDAR"."CAL_YEAR"
	,"D_CUSTOMER_SUB_GROUP"."CSB_ID"
	,"D_COUNTRY"."CTR_NAME"
ORDER BY
	1,2;

exec DBMS_STATS.GATHER_TABLE_STATS('DEMO_USR', 'MV_SALE_MODEL_LVL2_101');

DROP MATERIALIZED VIEW "DEMO_USR"."MV_SALE_MODEL_LVL2_102";

CREATE MATERIALIZED VIEW "DEMO_USR"."MV_SALE_MODEL_LVL2_102"
build immediate
enable query rewrite
AS
SELECT
	"D_CUSTOMER_SUB_GROUP"."CSB_ID"
	,COUNT(*)
	,sum(SAL_AMOUNT)
	,sum(SAL_DISCOUNT_AMOUNT)
FROM
	"DEMO_USR"."F_SALE" "F_SALE"
	,"DEMO_USR"."D_CUSTOMER" "D_CUSTOMER"
	,"DEMO_USR"."D_CUSTOMER_SUB_GROUP" "D_CUSTOMER_SUB_GROUP"
WHERE
	"F_SALE"."SAL_CUSTOMER" = "D_CUSTOMER"."CUS_ID"
	AND "D_CUSTOMER"."CUS_SUB_GROUP" = "D_CUSTOMER_SUB_GROUP"."CSB_ID"
GROUP BY
	"D_CUSTOMER_SUB_GROUP"."CSB_ID"
ORDER BY
	1,2;

exec DBMS_STATS.GATHER_TABLE_STATS('DEMO_USR', 'MV_SALE_MODEL_LVL2_102');


DROP DIMENSION dim1;

CREATE DIMENSION dim1
LEVEL CUSTOMER IS ("D_CUSTOMER"."CUS_ID")
LEVEL CUSTOMER_SUB_GROUP IS ("D_CUSTOMER_SUB_GROUP"."CSB_ID")
LEVEL CUSTOMER_GROUP IS ("D_CUSTOMER_GROUP"."CGR_ID")
HIERARCHY rollup
(CUSTOMER child of
CUSTOMER_SUB_GROUP child of
CUSTOMER_GROUP
JOIN KEY ("D_CUSTOMER"."CUS_SUB_GROUP") REFERENCES CUSTOMER_SUB_GROUP
JOIN KEY ("D_CUSTOMER_SUB_GROUP"."CSB_GROUP") REFERENCES CUSTOMER_GROUP
)
ATTRIBUTE CUSTOMER DETERMINES "D_CUSTOMER"."CUS_NAME"
ATTRIBUTE CUSTOMER_SUB_GROUP DETERMINES "D_CUSTOMER_SUB_GROUP"."CSB_DESC"
ATTRIBUTE CUSTOMER_GROUP DETERMINES "D_CUSTOMER_GROUP"."CGR_DESC"
;




alter system flush buffer_cache;
ALTER SESSION SET QUERY_REWRITE_ENABLED = 'true';

SELECT
	"D_CALENDAR"."CAL_YEAR"
	,"D_CUSTOMER_SUB_GROUP"."CSB_DESC"
	,"D_COUNTRY"."CTR_NAME"
	,COUNT(*)
	,sum(SAL_AMOUNT)
	,sum(SAL_DISCOUNT_AMOUNT)
FROM
	"DEMO_USR"."F_SALE" "F_SALE"
	,"DEMO_USR"."D_CUSTOMER" "D_CUSTOMER"
	,"DEMO_USR"."D_CUSTOMER_SUB_GROUP" "D_CUSTOMER_SUB_GROUP"
	,"DEMO_USR"."D_VENDOR" "D_VENDOR"
	,"DEMO_USR"."D_AGENCY" "D_AGENCY"
	,"DEMO_USR"."D_REGION" "D_REGION"
	,"DEMO_USR"."D_COUNTRY" "D_COUNTRY"
	,"DEMO_USR"."D_CALENDAR" "D_CALENDAR"
WHERE
	"F_SALE"."SAL_DATE" = "D_CALENDAR"."CAL_DATE"
	AND "F_SALE"."SAL_CUSTOMER" = "D_CUSTOMER"."CUS_ID"
	AND "D_CUSTOMER"."CUS_SUB_GROUP" = "D_CUSTOMER_SUB_GROUP"."CSB_ID"
	AND "D_REGION"."REG_COUNTRY" = "D_COUNTRY"."CTR_ID"
	AND "F_SALE"."SAL_VENDOR" = "D_VENDOR"."VDR_ID"
	AND "D_VENDOR"."VDR_AGENCY" = "D_AGENCY"."AGC_ID"
	AND "D_AGENCY"."AGC_REGION" = "D_REGION"."REG_ID"
	AND "D_REGION"."REG_COUNTRY" = "D_COUNTRY"."CTR_ID"
GROUP BY
	"D_CALENDAR"."CAL_YEAR"
	,"D_CUSTOMER_SUB_GROUP"."CSB_DESC"
	,"D_COUNTRY"."CTR_NAME"
ORDER BY
	1,2;




alter system flush buffer_cache;
ALTER SESSION SET QUERY_REWRITE_ENABLED = 'true';

SELECT
	"D_CUSTOMER_SUB_GROUP"."CSB_DESC"
	,COUNT(*)
	,sum(SAL_AMOUNT)
	,sum(SAL_DISCOUNT_AMOUNT)
FROM
	"DEMO_USR"."F_SALE" "F_SALE"
	,"DEMO_USR"."D_CUSTOMER" "D_CUSTOMER"
	,"DEMO_USR"."D_CUSTOMER_SUB_GROUP" "D_CUSTOMER_SUB_GROUP"
	,"DEMO_USR"."D_VENDOR" "D_VENDOR"
	,"DEMO_USR"."D_AGENCY" "D_AGENCY"
	,"DEMO_USR"."D_REGION" "D_REGION"
	,"DEMO_USR"."D_COUNTRY" "D_COUNTRY"
	,"DEMO_USR"."D_CALENDAR" "D_CALENDAR"
WHERE
	"F_SALE"."SAL_DATE" = "D_CALENDAR"."CAL_DATE"
	AND "F_SALE"."SAL_CUSTOMER" = "D_CUSTOMER"."CUS_ID"
	AND "D_CUSTOMER"."CUS_SUB_GROUP" = "D_CUSTOMER_SUB_GROUP"."CSB_ID"
	AND "D_REGION"."REG_COUNTRY" = "D_COUNTRY"."CTR_ID"
	AND "F_SALE"."SAL_VENDOR" = "D_VENDOR"."VDR_ID"
	AND "D_VENDOR"."VDR_AGENCY" = "D_AGENCY"."AGC_ID"
	AND "D_AGENCY"."AGC_REGION" = "D_REGION"."REG_ID"
	AND "D_REGION"."REG_COUNTRY" = "D_COUNTRY"."CTR_ID"
GROUP BY
"D_CUSTOMER_SUB_GROUP"."CSB_DESC"
;


SELECT
	"D_CUSTOMER_SUB_GROUP"."CSB_DESC"
	,COUNT(*)
	,sum(SAL_AMOUNT)
	,sum(SAL_DISCOUNT_AMOUNT)
FROM
	"DEMO_USR"."F_SALE" "F_SALE"
	,"DEMO_USR"."D_CUSTOMER" "D_CUSTOMER"
	,"DEMO_USR"."D_CUSTOMER_SUB_GROUP" "D_CUSTOMER_SUB_GROUP"
WHERE
	"F_SALE"."SAL_CUSTOMER" = "D_CUSTOMER"."CUS_ID"
	AND "D_CUSTOMER"."CUS_SUB_GROUP" = "D_CUSTOMER_SUB_GROUP"."CSB_ID"
GROUP BY
	"D_CUSTOMER_SUB_GROUP"."CSB_DESC"
ORDER BY
	1,2;